==> nateon-1.0.1.192.tar.bz2: nateon-1.0/nateon/dialog/filetransfer.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FILETRANSFER_H
#define FILETRANSFER_H

#include <qgroupbox.h>
#include <qlayout.h>
#include <qlistview.h>
#include <qprogressbar.h>
#include <qlabel.h>

#include <kmessagebox.h>
#include <kdebug.h>
#include "filetransferinterface.h"

class SendFileInfo;

/**
   @author Doo-Hyun Jang <ring0320@nate.com>
*/
class FileTransfer : public FileTransferForm
{
Q_OBJECT
public:
    FileTransfer(QWidget *parent = 0, const char *name = 0);
    ~FileTransfer();

    void showlist();
    void hidelist();
    void addListView(const QString & sFileCookie, const QString & sID, const QString & sFile, const int nSize, bool bSend);
    void cancelTransfer( const QString & sFileCookie );
    QListViewItem *getListViewItem( const QString & sFileCookie );
  
private slots:
    void slotUpdateInfo();
    void updateProgressByByte(const QString& sFileCookie, const unsigned long nByte);
    void endProgressByByte( const QString& sFileCookie );
	void slotCancelButton();
	
signals:
	void progressUpdate( int progress, int total );
	void cancelFileTransfer( const QString & );
};

#endif

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/dialog/filetransfer.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FILETRANSFER_H
#define FILETRANSFER_H

#include <qgroupbox.h>
#include <qlayout.h>
#include <qlistview.h>
#include <qprogressbar.h>
#include <qlabel.h>

#include <kmessagebox.h>
#include <kdebug.h>
#include "filetransferinterface.h"

class SendFileInfo;

/**
   @author Doo-Hyun Jang <ring0320@nate.com>
*/
class FileTransfer : public FileTransferForm {
    Q_OBJECT
public:
    FileTransfer(QWidget *parent = 0, const char *name = 0);
    ~FileTransfer();

    void showlist();
    void hidelist();
    void addListView(const QString & sFileCookie, const QString & sID, const QString & sFile, const int nSize, bool bSend);
    void cancelTransfer( const QString & sFileCookie );
    QListViewItem *getListViewItem( const QString & sFileCookie );

private slots:
    void slotUpdateInfo();
    void updateProgressByByte(const QString& sFileCookie, const unsigned long nByte);
    void endProgressByByte( const QString& sFileCookie );
    void slotCancelButton();

signals:
    void progressUpdate( int progress, int total );
    void cancelFileTransfer( const QString & );
};

#endif
